@@ -78,6 +78,12 @@ class G1:
             return NotImplemented
         return self.element != other.element
 
+    def is_neutral(self) -> bool:
+        return self.element.is_neutral()
+
+    def __nonzero__(self) -> bool:
+        return not self.element.is_neutral()
+
     def __hash__(self) -> int:
         return hash(self.element)
 
@@ -87,6 +93,9 @@ class G1:
     def __repr__(self) -> str:
         return f"G1({bytes(self)!r})"
 
+    def set_neutral(self) -> None:
+        self.element.set_neutral()
+
 
 def neutral_G1() -> G1:
     return G1(_relic.neutral_G1())
@@ -162,6 +171,12 @@ class G2:
             return NotImplemented
         return self.element != other.element
 
+    def is_neutral(self) -> bool:
+        return self.element.is_neutral()
+
+    def __nonzero__(self) -> bool:
+        return not self.element.is_neutral()
+
     def __hash__(self) -> int:
         return hash(self.element)
 
@@ -171,6 +186,9 @@ class G2:
     def __repr__(self) -> str:
         return f"G2({bytes(self)!r})"
 
+    def set_neutral(self) -> None:
+        self.element.set_neutral()
+
 
 def neutral_G2() -> G2:
     return G2(_relic.neutral_G2())
